# roundRect
## CanvasRenderingContext2D.roundRect() and Path2D.roundRect() polyfills

Implements the .roundRect() method of the CanvasPath mixin as introduced by https://github.com/whatwg/html/pull/6765

Currently passes all [related WPT tests](https://github.com/web-platform-tests/wpt/tree/master/html/canvas/element/path-objects).